@@ -92,7 +92,7 @@ tests = [
                              'test_overcloud_role_delete_dashdash_help',
                              'test_help_overcloud_role_delete'],
         'out_includes': [
-            '<ID>        ID of Overcloud Role to show.',
+            '<ROLE>      ID or name of the Overcloud Role to delete.',
         ],
         'out_excludes': [
             'overcloud-role-list',
@@ -138,7 +138,7 @@ tests = [
                              'test_overcloud_role_show_dashdash_help',
                              'test_help_overcloud_role_show'],
         'out_includes': [
-            '<ID>        ID of Overcloud Role to show.',
+            '<ROLE>      ID or name of the Overcloud Role to show.',
         ],
         'out_excludes': [
             'overcloud-role-list',
@@ -201,7 +201,7 @@ tests = [
                              'test_overcloud_delete_dashdash_help',
                              'test_help_overcloud_delete'],
         'out_includes': [
-            '<ID>        ID of Overcloud to show.',
+            '<OVERCLOUD>  ID or name of the Overcloud to delete.',
         ],
         'out_excludes': [
             'overcloud-list',
@@ -247,7 +247,7 @@ tests = [
                              'test_overcloud_show_dashdash_help',
                              'test_help_overcloud_show'],
         'out_includes': [
-            '<ID>        ID of Overcloud to show.',
+            '<OVERCLOUD>  ID or name of the Overcloud to show.',
         ],
         'out_excludes': [
             'overcloud-list',
@@ -277,6 +277,29 @@ tests = [
         ],
         'err_string': '',
         'return_code': 0,
+    },
+    # Overcloud - show template parameters
+    {
+        'commands': ['overcloud-show-template-parameters -h',
+                     'overcloud-show-template-parameters --help',
+                     'help overcloud-show-template-parameters'],
+        'test_identifiers': [
+            'test_overcloud_show_template_parameters_dash_h',
+            'test_overcloud_show_template_parameters_dashdash_help',
+            'test_help_overcloud_show_template_parameters'
+        ],
+        'out_includes': [
+            'Show the template parameters stored in the Tuskar API.'
+        ],
+        'out_excludes': [
+            '-n <NAME>, --name <NAME>'
+            'overcloud-list',
+            'overcloud-role-template-parameters',
+            '--os-username OS_USERNAME',
+            'Display help for <subcommand>',
+        ],
+        'err_string': '',
+        'return_code': 0,
     }
 ]
 
